import QtQuick 1.0
import Bauhaus 1.0
import HelperWidgets 1.0

QWidget {
    id: textSpecifics;

    layout: QVBoxLayout {
        topMargin: 0
        bottomMargin: 0
        leftMargin: 0
        rightMargin: 0
        spacing: 0

        GroupBox {
            id: standardTextGroupBox
            caption: qsTr("Time Field")
            layout: VerticalLayout {
                IntEditor {
                    backendValue: backendValues.hours
                    caption: qsTr("Hour")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

                IntEditor {
                    backendValue: backendValues.minutes
                    caption: qsTr("Minute")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

                QWidget {
                    layout: HorizontalLayout {
                        Label {
                            text: ""
                        }
                        CheckBox {
                            id: showSeconds
                            text: qsTr("Show Seconds")
                            backendValue: backendValues.showSeconds
                            baseStateFlag: isBaseState
                            checkable: true
                        }
                    }
                }

                IntEditor {
                    backendValue: backendValues.seconds
                    enabled: showSeconds.checked
                    caption: qsTr("Second")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

                QWidget {
                    layout: HorizontalLayout {
                        Label {
                            text: ""
                        }
                        CheckBox {
                            id: showPeriod
                            text: qsTr("Show Period")
                            backendValue: backendValues.showPeriod
                            baseStateFlag: isBaseState
                            checkable: true
                        }
                    }
                }

                QWidget {
                    layout: HorizontalLayout {
                        Label {
                            text: qsTr("Period")
                            toolTip: qsTr("Period")
                        }

                        ComboBox {
                            id: periodComboBox
                            enabled: showPeriod.checked
                            backendValue: backendValues.period
                            currentText: backendValues.period.value
                            baseStateFlag: isBaseState
                            items: ["AM", "PM"]
                            onItemsChanged: {
                                currentText =  backendValues.period.value;
                            }
                        }

                    }
                }

                QWidget {
                    layout: HorizontalLayout {
                        Label {
                            text: qsTr("Label Text")
                        }
                        LineEdit {
                            visible: !useLineEdit
                            backendValue: backendValues.labelText
                            baseStateFlag: isBaseState;
                            translation: true
                        }
                    }
                }

                IntEditor {
                    backendValue: backendValues.fieldSpacing
                    caption: qsTr("Field Spacing")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

            }
        }

        GroupBox {
            caption: qsTr("Color")
            layout: VerticalLayout {
                ColorGroupBox {
                    caption: qsTr("Input Color")
                    finished: finishedNotify

                    backendColor: backendValues.inputColor
                }
                ColorGroupBox {
                    caption: qsTr("Label Color")
                    finished: finishedNotify

                    backendColor: backendValues.labelColor
                }

            }
        }

        FontGroupBox {
            finished: finishedNotify;
            caption: qsTr("Input Font")
            fontFamily: backendValues.inputFontFamily
            pointSize: backendValues.inputFontPointSize
            pixelSize: backendValues.inputFontPixelSize
            boldStyle: backendValues.inputFontBold
            italicStyle: backendValues.inputFontItalic
            underlineStyle: backendValues.inputFontUnderline
            strikeoutStyle: backendValues.inputFontStrikeout
        }


        FontGroupBox {
            finished: finishedNotify;
            caption: qsTr("Label Font")
            fontFamily: backendValues.labelFontFamily
            pointSize: backendValues.labelFontPointSize
            pixelSize: backendValues.labelFontPixelSize
            boldStyle: backendValues.labelFontBold
            italicStyle: backendValues.labelFontItalic
            underlineStyle: backendValues.labelFontUnderline
            strikeoutStyle: backendValues.labelFontStrikeout
        }

        GroupBox {
            caption: qsTr("Time Picker Specifics")
            layout: VerticalLayout {
                IntEditor {
                    backendValue: backendValues.borderWidth
                    caption: qsTr("Border Width")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

                IntEditor {
                    backendValue: backendValues.borderRadius
                    caption: qsTr("Border Radius")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

                QWidget {
                    layout: HorizontalLayout {

                        ColorGroupBox {
                            caption: qsTr("Border Color")
                            finished: finishedNotify
                            backendColor: backendValues.borderColor
                        }
                    }
                }

                IntEditor {
                    backendValue: backendValues.spacing
                    caption: qsTr("Spacing")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

                ColorGroupBox {
                    caption: qsTr("Background Color")
                    finished: finishedNotify
                    backendColor: backendValues.backgroundColor
                }

                ColorGroupBox {
                    caption: qsTr("Button Background Color")
                    finished: finishedNotify
                    backendColor: backendValues.buttonBackgroundColor
                }

                QWidget {
                    layout: HorizontalLayout {
                        Label {
                            text: qsTr("Background Image")
                            toolTip: qsTr("Background Image")
                        }
                        UrlEdit {
                            backendValue: backendValues.keyboardBackGroundImage
                            baseStateFlag: isBaseState
                            filter: "*.png *.gif *.jpg *.bmp *.jpeg *.svg"
                            showComboBox: true
                        }
                    }
                }

                QWidget {
                    layout: HorizontalLayout {
                        Label {
                            text: qsTr("Caption Text")
                        }
                        LineEdit {
                            visible: !useLineEdit
                            backendValue: backendValues.caption
                            baseStateFlag: isBaseState;
                            translation: true
                        }
                    }
                }

                QWidget {
                    layout: HorizontalLayout {
                        ColorGroupBox {
                            caption: qsTr("Caption Text Color")
                            finished: finishedNotify
                            backendColor: backendValues.captionFontColor
                        }
                    }
                }

                QWidget {
                    layout: HorizontalLayout {
                        ColorGroupBox {
                            caption: qsTr("Time Text Color")
                            finished: finishedNotify
                            backendColor: backendValues.timeFontColor
                        }
                    }
                }

                QWidget {
                    layout: HorizontalLayout {
                        ColorGroupBox {
                            caption: qsTr("Button Text Color")
                            finished: finishedNotify
                            backendColor: backendValues.buttonFontColor
                        }
                    }
                }

                FontGroupBox{
                    caption: qsTr("Caption Text Font")
                    fontFamily: backendValues.captionFont_family
                    pixelSize: backendValues.captionFont_pixelSize
                    boldStyle: backendValues.captionFont_bold
                    italicStyle: backendValues.captionFont_italic
                    underlineStyle: backendValues.captionFont_underline
                    strikeoutStyle: backendValues.captionFont_strikeout
                }

                FontGroupBox{
                    caption: qsTr("Time Text Font")
                    fontFamily: backendValues.timeFont_family
                    pixelSize: backendValues.timeFont_pixelSize
                    boldStyle: backendValues.timeFont_bold
                    italicStyle: backendValues.timeFont_italic
                    underlineStyle: backendValues.timeFont_underline
                    strikeoutStyle: backendValues.timeFont_strikeout
                }

                FontGroupBox{
                    caption: qsTr("Button Text Font")
                    fontFamily: backendValues.buttonFont_family
                    pixelSize: backendValues.buttonFont_pixelSize
                    boldStyle: backendValues.buttonFont_bold
                    italicStyle: backendValues.buttonFont_italic
                    underlineStyle: backendValues.buttonFont_underline
                    strikeoutStyle: backendValues.buttonFont_strikeout
                }

            }
        }

        QScrollArea {
        }
    }
}
