import QtQuick 1.0
import Bauhaus 1.0
import HelperWidgets 1.0

QWidget {
    id: textSpecifics;

    layout: QVBoxLayout {
        topMargin: 0
        bottomMargin: 0
        leftMargin: 0
        rightMargin: 0
        spacing: 0

        GroupBox {
            id: standardTextGroupBox
            caption: qsTr("List Field")
            layout: VerticalLayout {
                IntEditor {
                    backendValue: backendValues.value
                    caption: qsTr("Value")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: -10000;
                    maximumValue: 10000;
                }

                QWidget {
                    layout: HorizontalLayout {
                        Label {
                            text: qsTr("Label Text")
                        }
                        LineEdit {
                            visible: !useLineEdit
                            backendValue: backendValues.labelText
                            baseStateFlag: isBaseState;
                            translation: true
                        }
                    }
                }

                IntEditor {
                    backendValue: backendValues.fieldSpacing
                    caption: qsTr("Field Spacing")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

            }
        }

        GroupBox {
            caption: qsTr("Color")
            layout: VerticalLayout {
                ColorGroupBox {
                    caption: qsTr("Input Color")
                    finished: finishedNotify
                    backendColor: backendValues.inputColor
                }

                ColorGroupBox {
                    caption: qsTr("Label Color")
                    finished: finishedNotify
                    backendColor: backendValues.labelColor
                }

            }
        }

        FontGroupBox {
            finished: finishedNotify;
            caption: qsTr("Input Font")
            fontFamily: backendValues.inputFontFamily
            pointSize: backendValues.inputFontPointSize
            pixelSize: backendValues.inputFontPixelSize
            boldStyle: backendValues.inputFontBold
            italicStyle: backendValues.inputFontItalic
            underlineStyle: backendValues.inputFontUnderline
            strikeoutStyle: backendValues.inputFontStrikeout
        }

        FontGroupBox {
            finished: finishedNotify;
            caption: qsTr("Label Font")
            fontFamily: backendValues.labelFontFamily
            pointSize: backendValues.labelFontPointSize
            pixelSize: backendValues.labelFontPixelSize
            boldStyle: backendValues.labelFontBold
            italicStyle: backendValues.labelFontItalic
            underlineStyle: backendValues.labelFontUnderline
            strikeoutStyle: backendValues.labelFontStrikeout
        }

        GroupBox {
            caption: qsTr("List Picker Specifics")
            layout: VerticalLayout {
                IntEditor {
                    backendValue: backendValues.borderWidth
                    caption: qsTr("Border Width")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

                IntEditor {
                    backendValue: backendValues.borderRadius
                    caption: qsTr("Border Radius")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

                QWidget {
                    layout: HorizontalLayout {
                        ColorGroupBox {
                            caption: qsTr("Border Color")
                            finished: finishedNotify
                            backendColor: backendValues.borderColor
                        }
                    }
                }

                IntEditor {
                    backendValue: backendValues.spacing
                    caption: qsTr("Spacing")
                    baseStateFlag: isBaseState;
                    step: 1;
                    minimumValue: 0;
                    maximumValue: 100;
                }

                ColorGroupBox {
                    caption: qsTr("Background Color")
                    finished: finishedNotify
                    backendColor: backendValues.backgroundColor
                }

                QWidget {
                    layout: HorizontalLayout {
                        Label {
                            text: qsTr("Background Image")
                            toolTip: qsTr("Background Image")
                        }
                        UrlEdit {
                            backendValue: backendValues.keyboardBackGroundImage
                            baseStateFlag: isBaseState
                            filter: "*.png *.gif *.jpg *.bmp *.jpeg *.svg"
                            showComboBox: true
                        }
                    }
                }

                QWidget {
                    layout: HorizontalLayout {
                        Label {
                            text: qsTr("Caption Text")
                        }
                        LineEdit {
                            visible: !useLineEdit
                            backendValue: backendValues.caption
                            baseStateFlag: isBaseState;
                            translation: true
                        }
                    }
                }

                QWidget {
                    layout: HorizontalLayout {
                        ColorGroupBox {
                            caption: qsTr("Caption Text Color")
                            finished: finishedNotify
                            backendColor: backendValues.captionFontColor
                        }
                    }
                }

                QWidget {
                    layout: HorizontalLayout {
                        ColorGroupBox {
                            caption: qsTr("List Text Color")
                            finished: finishedNotify
                            backendColor: backendValues.listFontColor
                        }
                    }
                }

                FontGroupBox{
                    caption: qsTr("Caption Text Font")
                    fontFamily: backendValues.captionFont_family
                    pixelSize: backendValues.captionFont_pixelSize
                    boldStyle: backendValues.captionFont_bold
                    italicStyle: backendValues.captionFont_italic
                    underlineStyle: backendValues.captionFont_underline
                    strikeoutStyle: backendValues.captionFont_strikeout
                }

                FontGroupBox{
                    caption: qsTr("List Text Font")
                    fontFamily: backendValues.listFont_family
                    pixelSize: backendValues.listFont_pixelSize
                    boldStyle: backendValues.listFont_bold
                    italicStyle: backendValues.listFont_italic
                    underlineStyle: backendValues.listFont_underline
                    strikeoutStyle: backendValues.listFont_strikeout
                }
            }
        }

        QScrollArea {
        }
    }
}


