import QtQuick 1.1
import "components"

/*
 * GPIO_I2C_Demo:
 *
 *  Sample application showing how to use the I2C bus from a QML application.
 *  Uses the 'system' plugin to 'execute' standard command-line binaries to
 *  read/write the G2H's GPIO Expander on the I2C bus.
 *
 *  Setup for use on a G2C1 4.3" Display Module.
 *
 *  The code in set_pin() and Component.onCompleted is specific to the
 *  TI PCA9534 Remote 8-Bit I2C I/O Expander.
 */

Rectangle {
    id: page
    width: 480
    height: 272

    property int sa: 0x3E               // GPIO Expander slave address
    property int inp: 0                 // port expander input port
    property int outp: 1                // port expander output port
    property int polarity_inversion: 2
    property int config: 3              // port expander config register


    System {
        id: system
    }

    AnimatedSwitch {
        id: animated_switch1
        x: 16
        y: 15
        width: 130
        height: 56
        on: false
        imageOn: ""
        textOffX: 78
        sliderImage: "images/knob.svg"
        textOnX: 18
        imageOff: "images/background.svg"
        sliderImageY: 2
        imageOffHeight: 56
        imageOffWidth: 130
        textColor: "#ffffff"
        font.family: "DejaVu Sans"
        font.bold: false
        sliderImageOffX: 78
        textOn: "On"
        sliderImageOnX: 1
        font.pixelSize: 22
        textOff: "Off"

        onOnChanged: {
            set_pin(0, on)
        }
    }

    AnimatedSwitch {
        id: animated_switch2
        x: 16
        y: 77
        width: 130
        height: 56
        on: false
        imageOn: ""
        textOffX: 78
        sliderImage: "images/knob.svg"
        textOnX: 18
        imageOff: "images/background.svg"
        sliderImageY: 2
        imageOffHeight: 56
        imageOffWidth: 130
        textColor: "#ffffff"
        font.family: "DejaVu Sans"
        font.bold: false
        sliderImageOffX: 78
        textOn: "On"
        sliderImageOnX: 1
        font.pixelSize: 22
        textOff: "Off"

        onOnChanged: {
            set_pin(1, on)
        }
    }

    AnimatedSwitch {
        id: animated_switch3
        x: 16
        y: 139
        width: 130
        height: 56
        on: false
        imageOn: ""
        textOffX: 78
        sliderImage: "images/knob.svg"
        textOnX: 18
        imageOff: "images/background.svg"
        sliderImageY: 2
        imageOffHeight: 56
        imageOffWidth: 130
        textColor: "#ffffff"
        font.family: "DejaVu Sans"
        font.bold: false
        sliderImageOffX: 78
        textOn: "On"
        sliderImageOnX: 1
        font.pixelSize: 22
        textOff: "Off"

        onOnChanged: {
            set_pin(2, on)
        }
    }

    AnimatedSwitch {
        id: animated_switch4
        x: 16
        y: 201
        width: 130
        height: 56
        on: false
        imageOn: ""
        textOffX: 78
        sliderImage: "images/knob.svg"
        textOnX: 18
        imageOff: "images/background.svg"
        sliderImageY: 2
        imageOffHeight: 56
        imageOffWidth: 130
        textColor: "#ffffff"
        font.family: "DejaVu Sans"
        font.bold: false
        sliderImageOffX: 78
        textOn: "On"
        sliderImageOnX: 1
        font.pixelSize: 22
        textOff: "Off"

        onOnChanged: {
            set_pin(3, on)
        }
    }

    AnimatedSwitch {
        id: animated_switch5
        x: 256
        y: 15
        width: 130
        height: 56
        on: false
        imageOn: ""
        textOffX: 78
        sliderImage: "images/knob.svg"
        textOnX: 18
        imageOff: "images/background.svg"
        sliderImageY: 2
        imageOffHeight: 56
        imageOffWidth: 130
        textColor: "#ffffff"
        font.family: "DejaVu Sans"
        font.bold: false
        sliderImageOffX: 78
        textOn: "On"
        sliderImageOnX: 1
        font.pixelSize: 22
        textOff: "Off"

        onOnChanged: {
            set_pin(4, on)
        }
    }

    AnimatedSwitch {
        id: animated_switch6
        x: 256
        y: 77
        width: 130
        height: 56
        on: false
        imageOn: ""
        textOffX: 78
        sliderImage: "images/knob.svg"
        textOnX: 18
        imageOff: "images/background.svg"
        sliderImageY: 2
        imageOffHeight: 56
        imageOffWidth: 130
        textColor: "#ffffff"
        font.family: "DejaVu Sans"
        font.bold: false
        sliderImageOffX: 78
        textOn: "On"
        sliderImageOnX: 1
        font.pixelSize: 22
        textOff: "Off"

        onOnChanged: {
            set_pin(5, on)
        }
    }

    AnimatedSwitch {
        id: animated_switch7
        x: 256
        y: 139
        width: 130
        height: 56
        on: false
        imageOn: ""
        textOffX: 78
        sliderImage: "images/knob.svg"
        textOnX: 18
        imageOff: "images/background.svg"
        sliderImageY: 2
        imageOffHeight: 56
        imageOffWidth: 130
        textColor: "#ffffff"
        font.family: "DejaVu Sans"
        font.bold: false
        sliderImageOffX: 78
        textOn: "On"
        sliderImageOnX: 1
        font.pixelSize: 22
        textOff: "Off"

        onOnChanged: {
            set_pin(6, on)
        }
    }

    AnimatedSwitch {
        id: animated_switch8
        x: 256
        y: 201
        width: 130
        height: 56
        on: false
        imageOn: ""
        textOffX: 78
        sliderImage: "images/knob.svg"
        textOnX: 18
        imageOff: "images/background.svg"
        sliderImageY: 2
        imageOffHeight: 56
        imageOffWidth: 130
        textColor: "#ffffff"
        font.family: "DejaVu Sans"
        font.bold: false
        sliderImageOffX: 78
        textOn: "On"
        sliderImageOnX: 1
        font.pixelSize: 22
        textOff: "Off"

        onOnChanged: {
            set_pin(7, on)
        }
    }

    Text {
        id: text1
        x: 172
        y: 31
        text: qsTr("LED 1")
        font.pixelSize: 20
    }

    Text {
        id: text2
        x: 172
        y: 93
        text: qsTr("LED 2")
        font.pixelSize: 20
    }

    Text {
        id: text3
        x: 172
        y: 155
        text: qsTr("LED 3")
        font.pixelSize: 20
    }

    Text {
        id: text4
        x: 172
        y: 217
        text: qsTr("LED 4")
        font.pixelSize: 20
    }

    Text {
        id: text5
        x: 412
        y: 31
        text: qsTr("LED 5")
        font.pixelSize: 20
    }

    Text {
        id: text6
        x: 412
        y: 93
        text: qsTr("LED 6")
        font.pixelSize: 20
    }

    Text {
        id: text7
        x: 412
        y: 155
        text: qsTr("LED 7")
        font.pixelSize: 20
    }

    Text {
        id: text8
        x: 412
        y: 217
        text: qsTr("LED 8")
        font.pixelSize: 20
    }

    /*
     * set_pin is an example of using javascript in a QML file
     */
    function set_pin(pin, state)
    {
        // convert pin number into bit mask
        var bit = (1 << pin);
        // create new bit setting
        var val = (state === true) ? (1 << pin) : 0;
        // get current output register value
        var ret = system.execute
                ("/usr/sbin/i2cget -y 1 %1 %2 b".arg(sa).arg(outp))
        // clear desired bit, OR in new setting
        var ret_val = (parseInt(ret) & ~bit) | val;
        // set new output register value
        system.execute
         ("/usr/sbin/i2cset -y 1 %1 %2 %3 b".arg(sa).arg(outp).arg(ret_val))
    }

    Component.onCompleted: {
        // setup GPIO port pins (all) as output
        system.execute
                ("/usr/sbin/i2cset -y 1 %1 %2 0x00 b".arg(sa).arg(config))
        // set pins to low (LEDs off)
        system.execute
                ("/usr/sbin/i2cset -y 1 %1 %2 0x00 b".arg(sa).arg(outp))
    }

}

