// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import "keycodes.js" as KeyCodes

Item {
    id: popupEditor

    property int animationSpeed: 200
    property string keyBACKSPACE: "\b"
    property string keyENTER: "\n"
    property alias bgImage: bgImage.source
    property alias label: labelItem
    property alias text: textItem
    property variant rootObject

    signal keyPress(string key)

    function show()
    {
        rootObject = popupEditor.parent;
        while (rootObject.parent)
            rootObject = rootObject.parent;

        //hide all child components
        //for(var i=0; i < rootObject.children.length; i++)
        //    rootObject.children[i].visible = false;


        popupEditor.parent = rootObject;
        popupEditor.width = rootObject.width;
        popupEditor.height = rootObject.height;
        popupEditor.x = 0//(rootObject.width - background.width)/2
        showAnim.from = rootObject.height;
        showAnim.to = 0//rootObject.height-background.height;
        showAnim.start();
    }

    function hide()
    {
        hideAnim.start();
        //show all child components
        //for(var i=0; i < rootObject.children.length; i++)
        //    rootObject.children[i].visible = true;
    }

    function handleKeyPress(key)
    {
        if (key === KeyCodes.keyBackspace) {
            if (text.text.length)
                text.text = text.text.substring(0, text.text.length-1);
        }
        else if (key !== KeyCodes.keyEnter)
            text.text += key;
        keyPress(key);
    }

    width: content.width
    height: content.height


    MouseArea {
        id: ma

        width: popupEditor.parent.width
        height: popupEditor.parent.height
        x: -popupEditor.x
        y: -(popupEditor.parent.height - popupEditor.height)
    }


   Image {
       id: bgImage
       source: "images/01_bg.bmp"
   }

   Column {
       Item {
           id: content
           width: 450
           height: Math.max(labelItem.font.pixelSize, textItem.font.pixelSize) + 20
           //anchors.left: parent.left
           //anchors.leftMargin: 30
           //anchors.top: parent.top
           //anchors.topMargin: 10

           Text {
               id: labelItem
               anchors.verticalCenter: parent.verticalCenter
               text: popupEditor.label.text
               font: popupEditor.label.font
               color: popupEditor.label.color
           }

           TextInput {
               id: textItem
               anchors.left: labelItem.right
               anchors.leftMargin: content.height / 2
               anchors.verticalCenter: parent.verticalCenter
               width: parent.width - labelItem.width - content.height / 2
               text: popupEditor.text.text
               font: popupEditor.text.font
               color: popupEditor.text.color
               focus: true
           }

           NumericKeypad {
               anchors.left: parent.left
               anchors.leftMargin: 120
               y: 25
               normalKeyIcon: "images/key_off.png"
               pressedlKeyIcon: "images/key_on.png"
               keySpacing: 0
               keyDefs: [
                   {keyCap: '1', keyCode: '1'},
                   {keyCap: '2', keyCode: '2'},
                   {keyCap: '3', keyCode: '3'},
                   {keyCap: '4', keyCode: '4'},
                   {keyCap: '5', keyCode: '5'},
                   {keyCap: '6', keyCode: '6'},
                   {keyCap: '7', keyCode: '7'},
                   {keyCap: '8', keyCode: '8'},
                   {keyCap: '9', keyCode: '9'},
                   {keyCap: '0', keyCode: '0'},
                   {keyCap: '', keyCode: KeyCodes.keyBackspace},
                   {keyCap: '', keyCode: KeyCodes.keyEnter}
               ]
           }

        }

   }

   PropertyAnimation {
        id: showAnim

        target: popupEditor
        property: "y"
        duration: animationSpeed
    }

    SequentialAnimation {
        id: hideAnim

        PropertyAnimation {
            target: popupEditor
            property: "y"
            to: popupEditor.parent.height
            duration: animationSpeed
        }
        ScriptAction {
            script: popupEditor.destroy()
        }
    }
}

