// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import "keycodes.js" as KeyCodes

Rectangle {
    id: control

    property alias label: labelItem
    property alias input: textItem
    property int fieldSpacing: 10


    width: labelStyle.width + inputStyle.width + fieldSpacing
    height: Math.max(labelStyle.font.pixelSize, inputStyle.font.pixelSize)
    clip: true

    Row {
        id: content

        spacing: control.fieldSpacing

        Text {
            id: labelItem

            anchors.verticalCenter: parent.verticalCenter
        }

        TextInput {
            id: textItem

            anchors.verticalCenter: parent.verticalCenter
        }
    }


    MouseArea {
        anchors.fill: parent
        z: 100
        onReleased: {
            var rootObject = control.parent;
            var keypad = popupEditor.createObject(control);
            if (keypad) {
                keypad.label.text = label.text;
                keypad.text.text = input.text;
                keypad.show();
            }
        }
    }

    Component {
        id: popupEditor

        PopupEditor {
            label.font: label.font
            text.font: input.font
            onKeyPress: {
                if (key === KeyCodes.keyBackspace) {
                    if (input.text.length)
                        input.text = input.text.substring(0,input.text.length-1);
                } else if (key === KeyCodes.keyEnter)
                    hide();
                else
                    input.text += key;
            }
        }
    }


}
