import QtQuick 2.0
import com.reachtech.systemplugin 1.0
import "components"

/*
 * GPIO_I2C_Demo:
 *
 *  Sample application showing how to use the I2C bus from a QML application.
 *  Uses the 'system' plugin to 'execute' standard command-line binaries to
 *  read/write the G2H's GPIO Expander on the I2C bus.
 *
 *  Setup for use on a G2H2-7R Display Module.
 *
 *  The code in set_pin() and Component.onCompleted is specific to the
 *  TI PCA9534 Remote 8-Bit I2C I/O Expander.
 */

Rectangle {
    id: page
    width: 800
    height: 480
    property int sa: 0x3E               // GPIO Expander slave address
    property int inp: 0                 // port expander input port
    property int outp: 1                // port expander output port
    property int polarity_inversion: 2
    property int config: 3              // port expander config register


    System {
        id: system
    }

    AnimatedSwitch {
        id: animatedSwitch1
        x: 250
        y: 17
        width: 130
        height: 56
        font.pixelSize: 22
        textOn: "On"
        sliderImageY: 2
        textOnX: 18
        font.bold: false
        textColor: "#ffffff"
        sliderImageOffX: 78
        imageOn: ""
        textOff: "Off"
        textOffX: 78
        imageOff: "images/background.svg"
        imageOffHeight: 56
        sliderImage: "images/knob.svg"
        font.family: "DejaVu Sans"
        imageOffWidth: 130
        sliderImageOnX: 1
        on: false

        onOnChanged: {
            set_pin(0, on)
        }
    }

    AnimatedSwitch {
        id: animatedSwitch2
        x: 250
        y: 73
        width: 130
        height: 56
        font.pixelSize: 22
        textOn: "On"
        sliderImageY: 2
        textOnX: 18
        font.bold: false
        textColor: "#ffffff"
        sliderImageOffX: 78
        imageOn: ""
        textOff: "Off"
        textOffX: 78
        imageOff: "images/background.svg"
        imageOffHeight: 56
        sliderImage: "images/knob.svg"
        font.family: "DejaVu Sans"
        imageOffWidth: 130
        sliderImageOnX: 1
        on: false

        onOnChanged: {
            set_pin(1, on)
        }
    }

    AnimatedSwitch {
        id: animatedSwitch3
        x: 250
        y: 129
        width: 130
        height: 56
        font.pixelSize: 22
        textOn: "On"
        sliderImageY: 2
        textOnX: 18
        font.bold: false
        textColor: "#ffffff"
        sliderImageOffX: 78
        imageOn: ""
        textOff: "Off"
        textOffX: 78
        imageOff: "images/background.svg"
        imageOffHeight: 56
        sliderImage: "images/knob.svg"
        font.family: "DejaVu Sans"
        imageOffWidth: 130
        sliderImageOnX: 1
        on: false

        onOnChanged: {
            set_pin(2, on)
        }
    }

    AnimatedSwitch {
        id: animatedSwitch4
        x: 250
        y: 185
        width: 130
        height: 56
        font.pixelSize: 22
        textOn: "On"
        sliderImageY: 2
        textOnX: 18
        font.bold: false
        textColor: "#ffffff"
        sliderImageOffX: 78
        imageOn: ""
        textOff: "Off"
        textOffX: 78
        imageOff: "images/background.svg"
        imageOffHeight: 56
        sliderImage: "images/knob.svg"
        font.family: "DejaVu Sans"
        imageOffWidth: 130
        sliderImageOnX: 1
        on: false

        onOnChanged: {
            set_pin(3, on)
        }
    }

    AnimatedSwitch {
        id: animatedSwitch5
        x: 250
        y: 241
        width: 130
        height: 56
        font.pixelSize: 22
        textOn: "On"
        sliderImageY: 2
        textOnX: 18
        font.bold: false
        textColor: "#ffffff"
        sliderImageOffX: 78
        imageOn: ""
        textOff: "Off"
        textOffX: 78
        imageOff: "images/background.svg"
        imageOffHeight: 56
        sliderImage: "images/knob.svg"
        font.family: "DejaVu Sans"
        imageOffWidth: 130
        sliderImageOnX: 1
        on: false

        onOnChanged: {
            set_pin(4, on)
        }
    }

    AnimatedSwitch {
        id: animatedSwitch6
        x: 250
        y: 297
        width: 130
        height: 56
        font.pixelSize: 22
        textOn: "On"
        sliderImageY: 2
        textOnX: 18
        font.bold: false
        textColor: "#ffffff"
        sliderImageOffX: 78
        imageOn: ""
        textOff: "Off"
        textOffX: 78
        imageOff: "images/background.svg"
        imageOffHeight: 56
        sliderImage: "images/knob.svg"
        font.family: "DejaVu Sans"
        imageOffWidth: 130
        sliderImageOnX: 1
        on: false

        onOnChanged: {
            set_pin(5, on)
        }
    }

    AnimatedSwitch {
        id: animatedSwitch7
        x: 250
        y: 353
        width: 130
        height: 56
        font.pixelSize: 22
        textOn: "On"
        sliderImageY: 2
        textOnX: 18
        font.bold: false
        textColor: "#ffffff"
        sliderImageOffX: 78
        imageOn: ""
        textOff: "Off"
        textOffX: 78
        imageOff: "images/background.svg"
        imageOffHeight: 56
        sliderImage: "images/knob.svg"
        font.family: "DejaVu Sans"
        imageOffWidth: 130
        sliderImageOnX: 1
        on: false

        onOnChanged: {
            set_pin(6, on)
        }
    }

    AnimatedSwitch {
        id: animatedSwitch8
        x: 250
        y: 409
        width: 130
        height: 56
        font.pixelSize: 22
        textOn: "On"
        sliderImageY: 2
        textOnX: 18
        font.bold: false
        textColor: "#ffffff"
        sliderImageOffX: 78
        imageOn: ""
        textOff: "Off"
        textOffX: 78
        imageOff: "images/background.svg"
        imageOffHeight: 56
        sliderImage: "images/knob.svg"
        font.family: "DejaVu Sans"
        imageOffWidth: 130
        sliderImageOnX: 1
        on: false

        onOnChanged: {
            set_pin(7, on)
        }
    }

    Text {
        id: text1
        x: 430
        y: 33
        text: qsTr("LED 1")
        font.pixelSize: 20
    }

    Text {
        id: text2
        x: 430
        y: 89
        text: "LED 2"
        font.pixelSize: 20
    }

    Text {
        id: text3
        x: 430
        y: 145
        text: "LED 3"
        font.pixelSize: 20
    }

    Text {
        id: text4
        x: 430
        y: 201
        text: "LED 4"
        font.pixelSize: 20
    }

    Text {
        id: text5
        x: 430
        y: 257
        text: "LED 5"
        font.pixelSize: 20
    }

    Text {
        id: text6
        x: 430
        y: 313
        text: "LED 6"
        font.pixelSize: 20
    }

    Text {
        id: text7
        x: 430
        y: 369
        text: "LED 7"
        font.pixelSize: 20
    }

    Text {
        id: text8
        x: 430
        y: 425
        text: qsTr("LED 8")
        font.pixelSize: 20
    }

    /*
     * set_pin is an example of using javascript in a QML file
     */
    function set_pin(pin, state)
    {
        // convert pin number into bit mask
        var bit = (1 << pin);
        // create new bit setting
        var val = (state === true) ? (1 << pin) : 0;
        // get current output register value
        var ret = system.execute
                ("/usr/sbin/i2cget -y 0 %1 %2 b".arg(sa).arg(outp))
        // clear desired bit, OR in new setting
        var ret_val = (parseInt(ret) & ~bit) | val;
        // set new output register value
        system.execute
         ("/usr/sbin/i2cset -y 0 %1 %2 %3 b".arg(sa).arg(outp).arg(ret_val))
    }

    Component.onCompleted: {
        // setup GPIO port pins (all) as output
        system.execute
                ("/usr/sbin/i2cset -y 0 %1 %2 0x00 b".arg(sa).arg(config))
        // set pins to low (LEDs off)
        system.execute
                ("/usr/sbin/i2cset -y 0 %1 %2 0x00 b".arg(sa).arg(outp))
    }

}

